; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10
;
;-| Advanced Moves |--------------------------------------------------------
[Command]
name = "Darkness"
command = ~D, B, F, z
time = 20

[Command]
name = "Darkness"
command = ~D, DB, B, F, z
time = 20

[Command]
name = "DAura"
command = ~B, D, F, c
time = 20

[Command]
name = "DAura"
command = ~B, DB, D, DF, F, c
time = 20

[Command]
name = "RBuster"
command = ~D, DF, F, x+y
time = 15

;-| Command Moves |--------------------------------------------------------
[Command]
name = "DSwipe"
command = ~D, DF, F, y
time = 15

[Command]
name = "DualB"
command = ~D, DF, F, z
time = 15

[Command]
name = "Cannon"
command = ~D, DB, B, z
time = 15

[Command]
name = "Hells"
command = ~D, DF, F, a
time = 15

[Command]
name = "Gospel01"
command = ~D, DB, B, a
time = 15

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "charge"
command = /$c
time = 1

[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.

[Statedef -1]


;===========================================================================
;---------------------------------------------------------------------------
;Darkness Overload
[State -1, Overload]
type = ChangeState
value = 1900
trigger1 = command = "Darkness"
trigger1 = statetype = S
trigger1 = power = 3000
trigger1 = ctrl

;---------------------------------------------------------------------------
;Dream Aura
[State -1, DAura]
type = ChangeState
value = 1100
trigger1 = command = "DAura"
trigger1 = statetype = S
trigger1 = power = 3000
trigger1 = Var(3) = 0
trigger1 = ctrl

;---------------------------------------------------------------------------
;Rapid Buster
[State -1, RBuster]
type = ChangeState
value = 1000
trigger1 = command = "RBuster"
trigger1 = statetype = S
trigger1 = power >= 1000
trigger1 = ctrl

;---------------------------------------------------------------------------
;Dark Swipe
[State -1, DSwipe]
type = ChangeState
value = 201
trigger1 = command = "DSwipe"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Dual Buster
[State -1, DualB]
type = ChangeState
value = 230
trigger1 = command = "DualB"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Cannon Chip
[State -1, Face]
type = ChangeState
value = 313
trigger1 = command = "Cannon"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Hells Rolling
[State -1, Hells]
type = ChangeState
value = 210
trigger1 = command = "Hells"
trigger1 = statetype = S
trigger1 = Power >= 500
trigger1 = ctrl

;---------------------------------------------------------------------------
;Gospel Slash
[State -1, Gospel01]
type = ChangeState
value = 315
trigger1 = command = "Gospel01"
trigger1 = statetype = S
trigger1 = Power >= 500
trigger1 = ctrl

;---------------------------------------------------------------------------
;Panel Breaker Hand
[State -1, x]
type = ChangeState
value = 310
trigger1 = command = "x"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Slashing Hand
[State -1, y]
type = ChangeState
value = 311
trigger1 = command = "y"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Omega Buster
[State -1, DSwipe]
type = ChangeState
value = 220
trigger1 = command = "x"
trigger1 = statetype = A
trigger1 = ctrl

[State -1, DSwipe]
type = ChangeState
value = 221
trigger1 = command = "y"
trigger1 = statetype = A
trigger1 = ctrl

[State -1, DSwipe]
type = ChangeState
value = 222
trigger1 = command = "z"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Diving smash
[State -1, DSmash]
type = ChangeState
value = 314
trigger1 = command = "a"
trigger1 = statetype = A
trigger1 = ctrl

[State -1, DSmash]
type = ChangeState
value = 314
trigger1 = command = "b"
trigger1 = statetype = A
trigger1 = ctrl

[State -1, DSmash]
type = ChangeState
value = 314
trigger1 = command = "c"
trigger1 = statetype = A
trigger1 = ctrl

;Test
[State -1, z]
type = ChangeState
value = 315
trigger1 = command = "start"
trigger1 = statetype = S
trigger1 = ctrl


;---------------------------------------------------------------------------
;Forte Buster
[State -1, z]
type = ChangeState
value = 300
trigger1 = command = "z"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Shove Hands
[State -1, a]
type = ChangeState
value = 312
trigger1 = command = "a"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Sword Hand
[State -1, b]
type = ChangeState
value = 290
trigger1 = command = "b"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Charging hand
[State -1, c]
type = ChangeState
value = 240
trigger1 = command = "charge"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Fwd
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Run Back
[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

;-------------------
;MEE Template Files
;   provided by
;  Kitsune Sniper
;       ***
; Thanks, Kitsune!
;-------------------
