; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10
;

;-| CPU Motions |--------------------------------------------------------
[Command]
name = "CPU1"
command = U,a+b+c+x+y+z+s
time = 1

[Command]
name = "CPU2"
command = D,a+b+c+x+y+z+s
time = 1

[Command]
name = "CPU3"
command = F,a+b+c+x+y+z+s
time = 1

[Command]
name = "CPU4"
command = B,a+b+c+x+y+z+s
time = 1

[Command]
name = "CPU5"
command = D,U,a+b+c+x+y+z+s
time = 1

[Command]
name = "CPU6"
command = D,D,a+b+c+x+y+z+s
time = 1

[Command]
name = "CPU7"
command = D,F,a+b+c+x+y+z+s
time = 1

[Command]
name = "CPU8"
command = D,B,a+b+c+x+y+z+s
time = 1

[Command]
name = "CPU9"
command = U,U,a+b+c+x+y+z+s
time = 1

[Command]
name = "CPU10"
command = U,D,a+b+c+x+y+z+s
time = 1

[Command]
name = "CPU11"
command = U,F,a+b+c+x+y+z+s
time = 1

[Command]
name = "CPU12"
command = U,B,a+b+c+x+y+z+s
time = 1

[Command]
name = "CPU13"
command = U,D,U,a+b+c+x+y+z+s
time = 1

[Command]
name = "CPU14"
command = U,D,D,a+b+c+x+y+z+s
time = 1

[Command]
name = "CPU15"
command = U,D,F,a+b+c+x+y+z+s
time = 1

[Command]
name = "CPU16"
command = U,D,B,a+b+c+x+y+z+s
time = 1

[Command]
name = "CPU17"
command = U,D,B,a+c+x+y+z+s
time = 1

;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;

;-| Special Motions |------------------------------------------------------
[Command]
name = "tuki"
command = a


[Command]
name = "FQC_a"
command = ~F, D, DF, a

[Command]
name = "FQC_b"
command = ~F, D, DF, b

[Command]
name = "FQC_c"
command = ~F, D, DF, c

[Command]
name = "BQC_a"
command = ~B, D, DB, a

[Command]
name = "BQC_b"
command = ~B, D, DB, b

[Command]
name = "BQC_c"
command = ~B, D, DB, c

[Command]
name = "QCF_a"
command = ~D, DF, F, a

[Command]
name = "QCF_b"
command = ~D, DF, F, b

[Command]
name = "QCF_c"
command = ~D, DF, F, c

[Command]
name = "QCB_a"
command = ~D, DB, B, a

[Command]
name = "QCB_b"
command = ~D, DB, B, b

[Command]
name = "QCB_c"
command = ~D, DB, B, c

[Command]
name = "QCF_x"
command = ~D, DF, F, x

[Command]
name = "BF_a"
command = ~B, F, a

[Command]
name = "BF_b"
command = ~B, F, b

[Command]
name = "BF_c"
command = ~B, F, c

[Command]
name = "3a"
command = a, a, a
time = 30

[Command]
name = "3b"
command = b, b, b
time = 25

[Command]
name = "3c"
command = c, c, c
time = 20
;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "s"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

[Command]
name = "BF"
command = B, F

[Command]
name = "FB"
command = F, B

[Command]
name = "c_jump_F"
command = UF
time = 5

[Command]
name = "c_jump_N"
command = U
time = 5

[Command]
name = "c_jump_B"
command = UB
time = 5
;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.

; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]
;===========================================================================
;CPU
[State -1]
type = VarSet
triggerall = Var(20) = 0
triggerall = win != 1
trigger1 = command = "CPU1"
trigger2 = command = "CPU2"
trigger3 = command = "CPU3"
trigger4 = command = "CPU4"
trigger5 = command = "CPU17"
trigger6 = command = "CPU5"
trigger7 = command = "CPU6"
trigger8 = command = "CPU7"
trigger9 = command = "CPU8"
trigger10 = command = "CPU9"
trigger11 = command = "CPU10"
trigger12 = command = "CPU11"
trigger13 = command = "CPU12"
trigger14 = command = "CPU13"
trigger15 = command = "CPU14"
trigger16 = command = "CPU15"
trigger17 = command = "CPU16"
v = 20
value = 1

;===========================================================================
[State -1]
type = ChangeState
value = 700
triggerall = command = "c_jump_F"
trigger1 = stateno >= 200
trigger1 = stateno <= 699
trigger1 = Pos Y > -80
trigger1 = movecontact = 1

[State -1]
type = ChangeState
value = 701
triggerall = command = "c_jump_N"
trigger1 = stateno >= 200
trigger1 = stateno <= 699
trigger1 = Pos Y > -80
trigger1 = movecontact = 1

[State -1]
type = ChangeState
value = 702
triggerall = command = "c_jump_B"
trigger1 = stateno >= 200
trigger1 = stateno <= 699
trigger1 = Pos Y > -80
trigger1 = movecontact = 1
;---------------------------------------------------------------------------
[State -1, Run Fwd]
type = ChangeState
value = 100
triggerall = command = "FF"
triggerall = statetype = S
trigger1 = ctrl
trigger2 = NumHelper(800) != 0
trigger2 = stateno = [120,159]

;---------------------------------------------------------------------------
;Run Back
;ރ_bV
[State -1, Run Back]
type = ChangeState
value = 105
triggerall = command = "BB"
triggerall = statetype = S
trigger1 = ctrl
trigger2 = NumHelper(800) != 0
trigger2 = stateno = [120,159]

;---------------------------------------------------------------------------
;Stand Light Punch
;p`
[State -1, Stand Light Punch]
type = ChangeState
value = 1100
triggerall = command = "tuki"
triggerall = statetype != A
trigger1 = ctrl
;trigger2 = stateno = 1201
;trigger2 = movecontact

---------------------------------------------------------------------------
;or[
[State -1, Stand Light Punch]
type = ChangeState
value = 1201
triggerall = command = "b"
triggerall = statetype != A
triggerall = power >= 1000
trigger1 = ctrl
;trigger2 = stateno =1100
;trigger2 = movecontact
---------------------------------------------------------------------------
;Stand Light Punch
;p`
;[State -1, Stand Light Punch]
;type = ChangeState
;value = 1300
;triggerall = command = "c"
;triggerall = statetype != A
;trigger1 = ctrl
;trigger2 = stateno = [1100,1201]
;trigger2 = movecontact
;---------------------------------------------------------------------------
;p`
[State -1, Stand Light Punch]
type = ChangeState
value = 1500
triggerall = command = "x"
triggerall = statetype != A
trigger1 = ctrl
;trigger2 = stateno = 1201
;trigger2 = movecontact

;---------------------------------------------------------------------------
;΂с[(air
[State -1]
type = ChangeState
value = 1400
triggerall = command = "b"
triggerall = statetype = A
triggerall = power >= 1000
trigger1 = ctrl
;trigger2 = stateno = 1300
;trigger2 = movecontact

;---------------------------------------------------------------------------
;˂(air
[State -1]
type = ChangeState
value = 11000
triggerall = command = "tuki"
triggerall = statetype = A
trigger1 = ctrl
;trigger2 = stateno = 1300
;trigger2 = movecontact


;---------------------------------------------------------------------------
;V
[State -1, ]
type = ChangeState
value = 10000
triggerall = Pos Y < -50
triggerall = Pos Y >= -210
triggerall = stateno != 10000
triggerall = stateno != 10001
triggerall = stateno != 10002
triggerall = stateno != 10003
triggerall = stateno != 10004
triggerall = movetype != H
triggerall = command = "holdup"
trigger1 = ctrl
;trigger2 = stateno = 1201
;trigger2 = movecontact

;---------------------------------------------------------------------------
;
[State -1]
type = ChangeState
value = 10005
triggerall = command = "x"
triggerall = statetype = A
trigger1 = ctrl
;trigger2 = stateno = 1300
;trigger2 = movecontact