;|==================|
;|Gutsman's command |
;|==================|
;Created By OnslaughtX

; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
; 
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10
; 

;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;
[Command]
name = "super_rock"
command = ~D, DF, F, x+y
time = 30

[Command]
name = "super_rock"
command = ~D, DF, F, x+z
time = 30

[Command]
name = "super_rock"
command = ~D, DF, F, z+y
time = 30

[Command]
name = "meteor_shower"
command = ~D, DB, B, x+y
time = 30

[Command]
name = "meteor_shower"
command = ~D, DB, B, z+y
time = 30

[Command]
name = "meteor_shower"
command = ~D, DB, B, x+z
time = 30

[Command]
name = "power_up"
command = ~D, DF, F, a+b
time = 30

[Command]
name = "power_up"
command = ~D, DF, F, c+b
time = 30

[Command]
name = "power_up"
command = ~D, DF, F, c+a
time = 30

[Command]
name = "defense_up"
command = ~D, DB, B, a+b
time = 30

[Command]
name = "defense_up"
command = ~D, DB, B, c+b
time = 30

[Command]
name = "defense_up"
command = ~D, DB, B, c+a
time = 30

[Command]
name = "soul_body"
command = ~30a

[Command]
name = "soul_body"
command = ~30b

[Command]
name = "soul_body"
command = ~30c

;-| Special Motions |------------------------------------------------------

[Command]
name = "rock_shield"
command = ~D, DB, B, x
time = 20

[Command]
name = "rock_shield"
command = ~D, DB, B, y
time = 20

[Command]
name = "rock_shield"
command = ~D, DB, B, z
time = 20

[Command]
name = "rock_throw"
command = ~D, DF, F, x
time = 20

[Command]
name = "rock_throw"
command = ~D, DF, F, y
time = 20

[Command]
name = "rock_throw"
command = ~D, DF, F, z
time = 20

[Command]
name = "tackle"
command = ~D, DF, F, a
time = 20

[Command]
name = "tackle"
command = ~D, DF, F, b
time = 20

[Command]
name = "tackle"
command = ~D, DF, F, c
time = 20

[Command]
name = "tackle2"
command = ~F, D, DF, a
time = 20

[Command]
name = "tackle2"
command = ~F, D, DF, b
time = 20

[Command]
name = "tackle2"
command = ~F, D, DF, c
time = 20

[Command]
name = "Kickx3"
command = a+b+c
time = 5

[Command]
name = "QCF_x"
command = ~D, DF, F, x

[Command]
name = "QCF_y"
command = ~D, DF, F, y

[Command]
name = "QCF_xy"
command = ~D, DF, F, x+y

[Command]
name = "QCB_a"
command = ~D, DF, F, a

[Command]
name = "QCB_b"
command = ~D, DF, F, b

[Command]
name = "FF_ab"
command = F, F, a+b

[Command]
name = "FF_a"
command = F, F, a

[Command]
name = "FF_b"
command = F, F, b

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

[Command]
name = "DownUp"
command = D, U
time = 20

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;-| CPU ONLY |--------------------------------------------------------------

[Command]
name = "CPU1"
command = U, D, B, F, s
time = 1

[Command]
name = "CPU2"
command = U, U, U, U, U, U
time = 1

[Command]
name = "CPU3"
command = D, D, D, D, D, D
time = 1

[Command]
name = "CPU4"
command = B, B, B, B, B, B
time = 1

[Command]
name = "CPU5"
command = F, F, F, F, F, F
time = 1

[Command]
name = "CPU6"
command = x, x, x, x, x, x
time = 1

[Command]
name = "CPU7"
command = y, y, y, y, y, y
time = 1

[Command]
name = "CPU8"
command = z, z, z, z, z, z
time = 1

[Command]
name = "CPU9"
command = a, a, a, a, a, a
time = 1

[Command]
name = "CPU10"
command = b, b, b, b, b, b
time = 1

[Command]
name = "CPU11"
command = c, c, c, c, c, c
time = 1

[Command]
name = "CPU12"
command = s, s, s, s, s, s
time = 1

[Command]
name = "CPU13"
command = U, D, B, F, x
time = 1

[Command]
name = "CPU14"
command = U, D, B, F, y
time = 1

[Command]
name = "CPU15"
command = U, D, B, F, z
time = 1

[Command]
name = "CPU16"
command = U, D, B, F, a
time = 1

[Command]
name = "CPU17"
command = U, D, B, F, b
time = 1

[Command]
name = "CPU18"
command = U, D, B, F, c
time = 1

[Command]
name = "CPU19"
command = U, U, D, D, B, B, F, F, x, x
time = 1

[Command]
name = "CPU20"
command = U, U, D, D, B, B, F, F, y, y
time = 1

[Command]
name = "CPU21"
command = U, U, D, D, B, B, F, F, z, z
time = 1

[Command]
name = "CPU22"
command = U, U, D, D, B, B, F, F, a, a
time = 1

[Command]
name = "CPU23"
command = U, U, D, D, B, B, F, F, b, b
time = 1

[Command]
name = "CPU24"
command = U, U, D, D, B, B, F, F, c, c
time = 1

[Command]
name = "CPU25"
command = U, U, D, D, B, B, F, F, s, s
time = 1

[Command]
name = "CPU26"
command = U, U, U, D, D, D, x, x, x
time = 1

[Command]
name = "CPU27"
command = U, U, U, D, D, D, y, y, y
time = 1

[Command]
name = "CPU28"
command = U, U, U, D, D, D, z, z, z
time = 1

[Command]
name = "CPU29"
command = U, U, U, D, D, D, a, a, a
time = 1

[Command]
name = "CPU30"
command = U, U, U, D, D, D, b, b, b
time = 1

[Command]
name = "CPU31"
command = U, U, U, D, D, D, c, c, c
time = 1

[Command]
name = "CPU32"
command = U, U, U, D, D, D, s, s, s
time = 1

[Command]
name = "CPU33"
command = U, U, U, D, D, D, U, U, U
time = 1

[Command]
name = "CPU34"
command = U, U, U, D, D, D, D, D, D
time = 1

[Command]
name = "CPU35"
command = U, U, U, D, D, D, B, B, B
time = 1

[Command]
name = "CPU36"
command = U, U, U, D, D, D, F, F, F
time = 1

[Command]
name = "CPU37"
command = B, B, B, F, F, F, x, x, x
time = 1

[Command]
name = "CPU38"
command = B, B, B, F, F, F, y, y, y
time = 1

[Command]
name = "CPU39"
command = B, B, B, F, F, F, z, z, z
time = 1

[Command]
name = "CPU40"
command = B, B, B, F, F, F, a, a, a
time = 1

[Command]
name = "CPU41"
command = B, B, B, F, F, F, b, b, b
time = 1

[Command]
name = "CPU42"
command = B, B, B, F, F, F, c, c, c
time = 1

[Command]
name = "CPU43"
command = B, B, B, F, F, F, s, s, s
time = 1

[Command]
name = "CPU44"
command = B, B, B, F, F, F, B, B, B
time = 1

[Command]
name = "CPU45"
command = B, B, B, F, F, F, F, F, F
time = 1

[Command]
name = "CPU46"
command = B, B, B, F, F, F, U, U, U
time = 1

[Command]
name = "CPU47"
command = B, B, B, F, F, F, D, D, D
time = 1

[Command]
name = "CPU48"
command = x, x, x, x, x, a, a, a, a, a
time = 1

[Command]
name = "CPU49"
command = y, y, y, y, y, b, b, b, b, b
time = 1

[Command]
name = "CPU50"
command = z, z, z, z, z, c, c, c, c, c, c
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.  
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;AI
[State -1]
type = varset
triggerall = roundstate = [1, 2]
trigger1 = command = "CPU50"
trigger2 = command = "CPU49"
trigger3 = command = "CPU48"
trigger4 = command = "CPU47"
trigger5 = command = "CPU46"
trigger6 = command = "CPU45"
trigger7 = command = "CPU44"
trigger8 = command = "CPU43"
trigger9 = command = "CPU42"
trigger10 = command = "CPU41"
trigger11 = command = "CPU40"
trigger12 = command = "CPU39"
trigger13 = command = "CPU38"
trigger14 = command = "CPU37"
trigger15 = command = "CPU36"
trigger16 = command = "CPU35"
trigger17 = command = "CPU34"
trigger18 = command = "CPU33"
trigger19 = command = "CPU32"
trigger20 = command = "CPU31"
trigger21 = command = "CPU30"
trigger22 = command = "CPU29"
trigger23 = command = "CPU28"
trigger24 = command = "CPU27"
trigger25 = command = "CPU26"
trigger26 = command = "CPU25"
trigger27 = command = "CPU24"
trigger28 = command = "CPU23"
trigger29 = command = "CPU22"
trigger30 = command = "CPU21"
trigger31 = command = "CPU20"
trigger32 = command = "CPU19"
trigger33 = command = "CPU18"
trigger34 = command = "CPU17"
trigger35 = command = "CPU16"
trigger36 = command = "CPU15"
trigger37 = command = "CPU14"
trigger38 = command = "CPU13"
trigger39 = command = "CPU12"
trigger40 = command = "CPU11"
trigger41 = command = "CPU10"
trigger42 = command = "CPU9"
trigger43 = command = "CPU8"
trigger44 = command = "CPU7"
trigger45 = command = "CPU6"
trigger46 = command = "CPU5"
trigger47 = command = "CPU4"
trigger48 = command = "CPU3"
trigger49 = command = "CPU2"
trigger50 = command = "CPU1"
var(4) = 1

;AI Diactivator
[State -1]
type = varset
trigger1 = command != "CPU50"
trigger1 = command != "CPU49"
trigger1 = command != "CPU48"
trigger1 = command != "CPU47"
trigger1 = command != "CPU46"
trigger1 = command != "CPU45"
trigger1 = command != "CPU44"
trigger1 = command != "CPU43"
trigger1 = command != "CPU42"
trigger1 = command != "CPU41"
trigger1 = command != "CPU40"
trigger1 = command != "CPU39"
trigger1 = command != "CPU38"
trigger1 = command != "CPU37"
trigger1 = command != "CPU36"
trigger1 = command != "CPU35"
trigger1 = command != "CPU34"
trigger1 = command != "CPU33"
trigger1 = command != "CPU32"
trigger1 = command != "CPU31"
trigger1 = command != "CPU30"
trigger1 = command != "CPU29"
trigger1 = command != "CPU28"
trigger1 = command != "CPU27"
trigger1 = command != "CPU26"
trigger1 = command != "CPU25"
trigger1 = command != "CPU24"
trigger1 = command != "CPU23"
trigger1 = command != "CPU22"
trigger1 = command != "CPU21"
trigger1 = command != "CPU20"
trigger1 = command != "CPU19"
trigger1 = command != "CPU18"
trigger1 = command != "CPU17"
trigger1 = command != "CPU16"
trigger1 = command != "CPU15"
trigger1 = command != "CPU14"
trigger1 = command != "CPU13"
trigger1 = command != "CPU12"
trigger1 = command != "CPU11"
trigger1 = command != "CPU10"
trigger1 = command != "CPU9"
trigger1 = command != "CPU8"
trigger1 = command != "CPU7"
trigger1 = command != "CPU6"
trigger1 = command != "CPU5"
trigger1 = command != "CPU4"
trigger1 = command != "CPU3"
trigger1 = command != "CPU2"
trigger1 = command != "CPU1"
trigger1 = command != "tackle"
trigger1 = command != "tackle2"
trigger1 = command != "Kickx3"
trigger1 = command != "DownUp"
trigger1 = command != "rock_throw"
trigger1 = command != "super_rock"
trigger1 = command != "power_up"
trigger1 = command != "defense_up"
trigger1 = command != "soul_body"
trigger1 = command != "meteor_shower"
trigger1 = command != "rock_shield"
trigger1 = command != "FF"
trigger1 = command != "BB"
trigger1 = command != "recovery"
trigger1 = command != "x"
trigger1 = command != "y"
trigger1 = command != "z"
trigger1 = command != "a"
trigger1 = command != "b"
trigger1 = command != "c"
trigger1 = command != "start"
trigger1 = command != "holdfwd"
trigger1 = command != "holdback"
trigger1 = command != "holdup"
trigger1 = command != "holddown"
trigger2 = roundstate = [3, 4]
var(4) = 0

[State -1, Meteor Shower]
type = changestate
value = 3010
trigger1 = numhelper(3) = 0
trigger1 = power >= 2000
trigger1 = command = "meteor_shower"
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Super Rock]
type = changestate
value = 3000
trigger1 = numhelper(2) = 0
trigger1 = power >= 1000
trigger1 = command = "super_rock"
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Soul Body]
type = null;changestate
value = 3030
trigger1 = power >= 1000
trigger1 = numhelper(5) = 0
trigger1 = command = "soul_body"
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Power Up]
type = changestate
value = 3020
trigger1 = var(2) = 0
trigger1 = power >= 1000
trigger1 = command = "power_up"
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Defense Up]
type = changestate
value = 3021
trigger1 = var(3) = 0
trigger1 = power >= 1000
trigger1 = command = "defense_up"
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Rock Shield]
type = changestate
value = 1030
trigger1 = numhelper(4) = 0
trigger1 = numhelper(5) = 0
trigger1 = numhelper(6) = 0
trigger1 = numhelper(7) = 0
trigger1 = numhelper(8) = 0
trigger1 = numhelper(9) = 0
trigger1 = numhelper(10) = 0
trigger1 = numhelper(11) = 0
trigger1 = numhelper(12) = 0
trigger1 = numhelper(13) = 0
trigger1 = numhelper(14) = 0
trigger1 = command = "rock_shield"
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Rock Throw]
type = changestate
value = 1010
trigger1 = numhelper(1) = 0
trigger1 = command = "rock_throw"
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Tackle2]
type = changestate
value = 1020
trigger1 = command = "tackle2"
trigger1 = var(0) = 0
trigger1 = ctrl

[State -1, Tackle]
type = changestate
value = 1000
trigger1 = command = "tackle"
trigger1 = var(0) = 0
trigger1 = ctrl

[State -1, Taunt]
type = changestate
value = 1105
trigger1 = command = "start"
trigger1 = statetype != A
trigger1 = ctrl

[State -1, 2]
type = null;changestate
value = 40
triggerall = ctrl
triggerall = stateno = 0
triggerall = statetype = S
trigger1 = command = "holdback"
trigger2 = command = "holdfwd"

[State -1, 3]
type = changestate
value = 100
triggerall = ctrl
triggerall = statetype != A
triggerall = var(4) = 0
trigger1 = command = "FF"

[State -1, 4]
type = changestate
value = 105
triggerall = ctrl
triggerall = statetype != A
triggerall = var(4) = 0
trigger1 = command = "BB"

[State -1, 5]
type = changestate
value = 1100
triggerall = ctrl
triggerall = statetype != A
triggerall = var(4) = 0
trigger1 = command = "DownUp"
trigger2 = command = "Kickx3"

[State -1, 6]
type = varadd
trigger1 = var(2) > 0
var(2) = -1

[State -1, 7]
type = varadd
trigger1 = var(3) > 0
var(3) = -1