; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10
;

;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;
[Command]
name = "rakuhouha"
command = ~D, DF, F, D, DF, F, b
time = 30

[Command]
name = "darkhold"
command = ~z
time = 30

;-| Special Motions |------------------------------------------------------

[Command]
name = "twindream"
command = ~D, DF, F, y

[Command]
name = "shoryuken"
command = ~D, DF, F, b

[Command]
name = "pressback"
command = ~B

;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

[Command]
name = "BF"
command = B, F
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

[Command]
name = "back"
command = B
time = 1

[Command]
name = "fwd"
command = F
time = 1

[Command]
name = "up"
command = U
time = 1

[Command]
name = "down"
command = D
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]
;===========================================================================
;Special Attacks
;---------------------------------------------------------------------------
;===========================================================================
;---------------------------------------------------------------------------
;Dark Hold
;[State -1, Dark Hold]
;type = ChangeState
;value = 545
;triggerall = command = "darkhold" && Power >= 2
;trigger1 = Var(49) = 0
;trigger1 = Var(30) = 1
;trigger1 = statetype = S
;trigger1 = ctrl

;---------------------------------------------------------------------------
;Twin Dream
;[State -1, Twin Dream]
;type = ChangeState
;value = 535
;triggerall = command = "twindream" && Power >= 1000
;trigger1 = Var(49) = 0
;trigger1 = Var(30) = 1
;trigger1 = statetype = S
;trigger1 = ctrl

;---------------------------------------------------------------------------
;Sky Haltz/Kuuenbu
[State -1, Sky Haltz]
type = ChangeState
value = 45
triggerall = Var(2) = 0
trigger1 = Pos Y != 0
trigger1 = command = "up"
trigger1 = time > 9
trigger1 = StateType = A
persistent = 0

;---------------------------------------------------------------------------
;Flying Jump/Hienkyaku
[State -1, Flying Jump]
type = ChangeState
value = 200
triggerall = Var(2) = 0
trigger1 = command = "FF"
trigger1 = StateType = A

;---------------------------------------------------------------------------
;Fallen Phoenix Crush/Rakuhouha
[State -1, Fallen Phoenix Crush]
type = ChangeState
value = 520
triggerall = command = "rakuhouha" && Power >= 1500
triggerall = Var(30) = 0 || Var(30) = 1
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Electric Blade
[State -1, Electric Blade]
type = ChangeState
value = 540
triggerall = command = "shoryuken"
triggerall = Var(30) = 1
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = statetype = S
trigger2 = stateno = 101 || stateno = 100

;---------------------------------------------------------------------------
;Dragon Flame Blade/Ryuenjin
[State -1, Dragon Flame Blade]
type = ChangeState
value = 515
triggerall = command = "shoryuken"
triggerall = Var(30) = 0
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = statetype = S
trigger2 = stateno = 101 || stateno = 100

;---------------------------------------------------------------------------
;Thunder God Attack/Raijingeki
[State -1, Thunder God Attack]
type = ChangeState
value = 500
triggerall = command = "b"
triggerall = Var(30) = 0 || Var(30) = 1
trigger1 = PalNo = 1 
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = NumProj = 0
trigger2 = PalNo = 4
trigger2 = statetype = S
trigger2 = ctrl
trigger2 = NumProj = 0

;---------------------------------------------------------------------------
;Hurricane Fang/Shippuga
[State -1, Hurricane Fang]
type = ChangeState
value = 505
triggerall = command = "b"
trigger1 = Var(30) = 0
trigger1 = statetype = S
trigger1 = StateNo = 100

;---------------------------------------------------------------------------
;Ice Stab/Hyourestuzan
[State -1, Ice Stab]
type = ChangeState
value = 510
triggerall = command = "holddown" && command = "b"
trigger1 = Var(30) = 0
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Z Buster
[State -1, Z Buster]
type = ChangeState
value = 525
triggerall = Var(30) = 1
triggerall = command = "b"
trigger1 = statetype = S
trigger1 = ctrl
trigger1 = NumProj = 0

;---------------------------------------------------------------------------
;Quake Blazer
[State -1, Quake Blazer]
type = ChangeState
value = 530
triggerall = command = "holddown" && command = "b"
trigger1 = Var(30) = 1
trigger1 = statetype = A
trigger1 = ctrl

;===========================================================================
;---------------------------------------------------------------------------
;Run Fwd
;_bV
[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = command = "BF"
trigger2 = statetype = S
trigger2 = ctrl

;===========================================================================
;---------------------------------------------------------------------------
;Espada Mdia
[State -1, Medium Sword]
type = ChangeState
value = 305
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = StateNo = 300 && Time < 15

;---------------------------------------------------------------------------
;Espada Forte
[State -1, Strong Sword]
type = ChangeState
value = 310
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = stateno = 305 && time < 15

;---------------------------------------------------------------------------
;Espada Fraca
[State -1, Weak Sword]
type = ChangeState
value = 300
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
;Espada Fraca Agachado
[State -1, Espada Fraca Agachado]
type = ChangeState
value = 330
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl

;---------------------------------------------------------------------------
;Espada Mdia Agachado
[State -1, Espada Mdia Agachado]
type = ChangeState
value = 335
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 330
trigger2 = time > 9 && Movehit

;---------------------------------------------------------------------------
;Espada Forte Agachado
[State -1, Espada Forte Agachado]
type = ChangeState
value = 340
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = stateno = 335
trigger2 = time > 9 && Movehit

;---------------------------------------------------------------------------
;Espada Mdia Area
[State -1, Espada Mdia Area]
type = ChangeState
value = 320
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = StateNo = 315 && Movehit

;---------------------------------------------------------------------------
;Espada Forte Area
[State -1, Espada Forte Area]
type = ChangeState
value = 325
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl

;---------------------------------------------------------------------------
;Espada Fraca Area
[State -1, Espada Fraca Area]
type = ChangeState
value = 315
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl
